==> codemirror-theme-abyss-4.21.10.tgz: package/esm/index.js <==
import _extends from "@babel/runtime/helpers/extends";
import { tags as t } from '@lezer/highlight';
import { createTheme } from '@uiw/codemirror-themes';
import { config } from './color';
export var defaultSettingsAbyss = {
  background: config.background,
  foreground: config.foreground,
  caret: config.cursor,
  selection: config.selection,
  selectionMatch: config.selection,
  gutterBackground: config.background,
  gutterForeground: config.foreground,
  lineHighlight: config.activeLine
};
export var abyssInit = options => {
  var {
    theme = 'dark',
    settings = {},
    styles = []
  } = options || {};
  return createTheme({
    theme: theme,
    settings: _extends({}, defaultSettingsAbyss, settings),
    styles: [{
      tag: t.keyword,
      color: config.keyword
    }, {
      tag: [t.name, t.deleted, t.character, t.macroName],
      color: config.variable
    }, {
      tag: [t.propertyName],
      color: config.function
    }, {
      tag: [t.processingInstruction, t.string, t.inserted, t.special(t.string)],
      color: config.string
    }, {
      tag: [t.function(t.variableName), t.labelName],
      color: config.function
    }, {
      tag: [t.color, t.constant(t.name), t.standard(t.name)],
      color: config.constant
    }, {
      tag: [t.definition(t.name), t.separator],
      color: config.variable
    }, {
      tag: [t.className],
      color: config.class
    }, {
      tag: [t.number, t.changed, t.annotation, t.modifier, t.self, t.namespace],
      color: config.number
    }, {
      tag: [t.typeName],
      color: config.type,
      fontStyle: config.type
    }, {
      tag: [t.operator, t.operatorKeyword],
      color: config.keyword
    }, {
      tag: [t.url, t.escape, t.regexp, t.link],
      color: config.regexp
    }, {
      tag: [t.meta, t.comment],
      color: config.comment
    }, {
      tag: t.tagName,
      color: config.tag
    }, {
      tag: t.strong,
      fontWeight: 'bold'
    }, {
      tag: t.emphasis,
      fontStyle: 'italic'
    }, {
      tag: t.link,
      textDecoration: 'underline'
    }, {
      tag: t.heading,
      fontWeight: 'bold',
      color: config.heading
    }, {
      tag: [t.atom, t.bool, t.special(t.variableName)],
      color: config.variable
    }, {
      tag: t.invalid,
      color: config.invalid
    }, {
      tag: t.strikethrough,
      textDecoration: 'line-through'
    }, ...styles]
  });
};
export var abyss = abyssInit();

==> codemirror-theme-abyss-4.21.11.tgz: package/esm/index.js <==
import _extends from "@babel/runtime/helpers/extends";
import { tags as t } from '@lezer/highlight';
import { createTheme } from '@uiw/codemirror-themes';
import { config } from './color';
export var defaultSettingsAbyss = {
  background: config.background,
  foreground: config.foreground,
  caret: config.cursor,
  selection: config.selection,
  selectionMatch: config.selectionMatch,
  gutterBackground: config.background,
  gutterForeground: config.foreground,
  lineHighlight: config.activeLine
};
export var abyssInit = options => {
  var {
    theme = 'dark',
    settings = {},
    styles = []
  } = options || {};
  return createTheme({
    theme: theme,
    settings: _extends({}, defaultSettingsAbyss, settings),
    styles: [{
      tag: t.keyword,
      color: config.keyword
    }, {
      tag: [t.name, t.deleted, t.character, t.macroName],
      color: config.variable
    }, {
      tag: [t.propertyName],
      color: config.function
    }, {
      tag: [t.processingInstruction, t.string, t.inserted, t.special(t.string)],
      color: config.string
    }, {
      tag: [t.function(t.variableName), t.labelName],
      color: config.function
    }, {
      tag: [t.color, t.constant(t.name), t.standard(t.name)],
      color: config.constant
    }, {
      tag: [t.definition(t.name), t.separator],
      color: config.variable
    }, {
      tag: [t.className],
      color: config.class
    }, {
      tag: [t.number, t.changed, t.annotation, t.modifier, t.self, t.namespace],
      color: config.number
    }, {
      tag: [t.typeName],
      color: config.type,
      fontStyle: config.type
    }, {
      tag: [t.operator, t.operatorKeyword],
      color: config.keyword
    }, {
      tag: [t.url, t.escape, t.regexp, t.link],
      color: config.regexp
    }, {
      tag: [t.meta, t.comment],
      color: config.comment
    }, {
      tag: t.tagName,
      color: config.tag
    }, {
      tag: t.strong,
      fontWeight: 'bold'
    }, {
      tag: t.emphasis,
      fontStyle: 'italic'
    }, {
      tag: t.link,
      textDecoration: 'underline'
    }, {
      tag: t.heading,
      fontWeight: 'bold',
      color: config.heading
    }, {
      tag: [t.atom, t.bool, t.special(t.variableName)],
      color: config.variable
    }, {
      tag: t.invalid,
      color: config.invalid
    }, {
      tag: t.strikethrough,
      textDecoration: 'line-through'
    }, ...styles]
  });
};
export var abyss = abyssInit();
